### Name: plotLMER.fnc
### Title: plot a mer object
### Aliases: plotLMER.fnc
### Keywords: regression

### ** Examples

  ## Not run: 
##D 
##D #############################################################
##D # fitting a cosine with a spline (simulated data)
##D #############################################################
##D 
##D require("Design", quietly=TRUE, character=TRUE)
##D dfr = makeSplineData.fnc()
##D table(dfr$Subject)
##D xylowess.fnc(Y ~ X | Subject, data = dfr)
##D # the smoother doesn't recognize the cosine function implemented in makeSplineData.fnc()
##D dev.off()   
##D 
##D dfr.lmer = lmer(Y ~ rcs(X, 5) + (1|Subject), data = dfr)
##D plotLMER.fnc(dfr.lmer)
##D 
##D # comparison with ols from Design package
##D dfr.dd = datadist(dfr)
##D options(datadist='dfr.dd')
##D dfr.ols = ols(Y~Subject+rcs(X), data=dfr, x=T, y=T)
##D dfr$fittedOLS = fitted(dfr.ols)
##D dfr$fittedLMER = as.vector(dfr.lmer@X %*% fixef(dfr.lmer))
##D 
##D # we plot the lmer() fit in blue, the ols() fit in red (both adjusted for
##D # subject S1), and plot the underlying model in green
##D 
##D plot(dfr[dfr$Subject=="S1",]$X, dfr[dfr$Subject=="S1",]$fittedLMER +
##D   ranef(dfr.lmer)[[1]]["S1",], type="l", col="blue",
##D   ylim = range(dfr$y + ranef(dfr.lmer)[[1]]["S1",],
##D   dfr[dfr$Subject == "S1",]$fittedLMER,
##D   dfr[dfr$Subject == "S1",]$fittedOLS),
##D   xlab="X", ylab="Y")   
##D lines(dfr[dfr$Subject=="S1",]$X, dfr[dfr$Subject=="S1",]$fittedOLS, 
##D col="red")
##D lines(dfr[dfr$Subject=="S1",]$X, dfr[dfr$Subject=="S1",]$y+
##D ranef(dfr.lmer)[[1]]["S1",], col="green")
##D legend(2,29,c("30+cos(x)", "lmer (S1)", "ols (S1)"), lty=rep(1,3), 
##D col=c("green", "blue", "red"))
##D 
##D 
##D 
##D #############################################################
##D # a model with a raw polynomial: the mcmc credible intervals
##D # will be different each time this example is run; for large
##D # numbers of samples, the plotting code will become quite slow
##D #############################################################
##D 
##D bg.lmer = lmer(LogRT ~ PC1+PC2+PC3 + ReadingScore +
##D poly(OrthLength, 2, raw=TRUE) + LogFrequency + LogFamilySize +
##D (1|Word) + (1|Subject)+(0+OrthLength|Subject) +
##D (0+LogFrequency|Subject), data = beginningReaders)
##D mcmc = pvals.fnc(bg.lmer, nsim=1000, withMCMC=TRUE)
##D 
##D pars = par()
##D par(mfrow=c(3,3), mar=c(5,5,1,1))
##D plotLMER.fnc(bg.lmer, mcmcMat=mcmc$mcmc, fun=exp, ylabel = "RT (ms)")
##D 
##D #############################################################
##D # a model with an interaction involving numeric predictors
##D #############################################################
##D 
##D danish.lmer = lmer(LogRT ~ PC1 + PC2 + PrevError + Rank +
##D ResidSemRating + ResidFamSize + LogWordFreq*LogAffixFreq*Sex +  
##D poly(LogCUP, 2, raw=TRUE) + LogUP + LogCUPtoEnd + 
##D (1|Subject) + (1|Word) + (1|Affix), data = danish)
##D danish.lmerA = lmer(LogRT ~ PC1 + PC2 + PrevError + Rank +
##D ResidSemRating + ResidFamSize + LogWordFreq*LogAffixFreq*Sex +  
##D poly(LogCUP, 2, raw=TRUE) + LogUP + LogCUPtoEnd + 
##D (1|Subject) + (1|Word) + (1|Affix), data = danish,
##D subset=abs(scale(resid(danish.lmer)))<2.5)
##D mcmc = pvals.fnc(danish.lmerA, nsim=10000, withMCMC=TRUE)
##D mcmc$fixed[,1:5]
##D 
##D # this model has a significant three-way interaction
##D # for visualization, we split the data by the sex of the subject
##D 
##D males = danish[abs(scale(resid(danish.lmer)))<2.5 & danish$Sex=="M",]
##D females = danish[abs(scale(resid(danish.lmer)))<2.5 & danish$Sex=="F",]
##D 
##D # we now fit individual models to these subsets of the data
##D 
##D males.lmer = lmer(LogRT ~ PC1 + PC2 + PrevError + Rank +
##D ResidSemRating + ResidFamSize + LogWordFreq*LogAffixFreq +  
##D poly(LogCUP, 2, raw=TRUE) + LogUP + LogCUPtoEnd + 
##D (1|Subject) + (1|Word) + (1|Affix), data = males)
##D females.lmer = lmer(LogRT ~ PC1 + PC2 + PrevError + Rank +
##D ResidSemRating + ResidFamSize + LogWordFreq*LogAffixFreq +  
##D poly(LogCUP, 2, raw=TRUE) + LogUP + LogCUPtoEnd + 
##D (1|Subject) + (1|Word) + (1|Affix), data = females)
##D femMCMC = pvals.fnc(females.lmer, nsim=500, withMCMC=TRUE, addPlot=FALSE)
##D 
##D # for which we then plot the interaction 
##D # of word frequency by affix frequency 
##D 
##D par(mfrow=c(2,2),mar=c(5,5,2,2))
##D plotLMER.fnc(females.lmer, pred = "LogAffixFreq", 
##D intr=list("LogWordFreq", round(quantile(females$LogWordFreq),3), "beg",
##D list(c("red", "green", "blue", "yellow", "purple"), rep(1,5))), ylimit=c(6.5,7.0),
##D mcmcMat=femMCMC$mcmc, xlabel = "log affix frequency", ylabel = "log RT auditory lexical decision")
##D mtext("females", line=0.5, cex=0.8)
##D plotLMER.fnc(males.lmer, pred = "LogAffixFreq", 
##D intr=list("LogWordFreq", round(quantile(males$LogWordFreq),3), "beg",
##D list(c("red", "green", "blue", "yellow", "purple"), 1:5)),
##D ylimit=c(6.5,7.0))
##D mtext("males", line=0.5, cex=0.8)
##D plotLMER.fnc(females.lmer, pred = "LogWordFreq", 
##D intr=list("LogAffixFreq", round(quantile(females$LogAffixFreq),3), "beg"),
##D ylimit=c(6.5,7.0), cexsize=1.2)
##D mtext("females", line=0.5, cex=0.8)
##D plotLMER.fnc(males.lmer, pred = "LogWordFreq", 
##D intr=list("LogAffixFreq", round(quantile(males$LogAffixFreq),3), "end"),
##D ylimit=c(6.5,7.0), cexsize=1.0)
##D mtext("males", line=0.5, cex=0.8)
##D par(mfrow=c(1,1))
##D 
##D #############################################################
##D # plotting an interaction between two factors
##D #############################################################
##D 
##D danish$WordFreqFac = danish$LogWordFreq > median(danish$LogWordFreq)
##D danish.lmer2 = lmer(LogRT ~ WordFreqFac*Sex +  
##D (1|Subject) + (1|Word) + (1|Affix), data = danish)
##D mcmc = pvals.fnc(danish.lmer2,nsim=1000,withMCMC=TRUE)
##D 
##D plotLMER.fnc(danish.lmer2, pred = "Sex", 
##D intr=list("WordFreqFac", c("TRUE", "FALSE"), "end", 
##D list(c("red",  "blue"), rep(1,2))),
##D ylimit=c(6.5,7.0), cexsize=1.0, addlines=TRUE, mcmcMat=mcmc$mcmc)
##D 
##D #############################################################
##D # a generalized linear mixed-effects model
##D #############################################################
##D 
##D dative.lmer = lmer(RealizationOfRecipient ~ 
##D AccessOfTheme + AccessOfRec + LengthOfRecipient + AnimacyOfRec +
##D AnimacyOfTheme + PronomOfTheme + DefinOfTheme + LengthOfTheme +
##D SemanticClass + Modality + (1|Verb), 
##D data = dative, family = "binomial")
##D 
##D par(mfrow=c(3,4),mar=c(5,5,1,1))
##D plotLMER.fnc(dative.lmer, fun=plogis, addlines=TRUE)
##D 
##D # with user-specified labels for the x-axis
##D par(mfrow=c(3,4),mar=c(5,5,1,1))
##D plotLMER.fnc(dative.lmer, fun=plogis, addlines=TRUE,
##D xlabs=unlist(strsplit("abcdefghij","")))
##D 
##D par(pars)
##D 
##D   
## End(Not run)



