### Name: betadisper
### Title: Multivariate homogeneity of groups dispersions (variances)
### Aliases: betadisper scores.betadisper anova.betadisper plot.betadisper
###   boxplot.betadisper print.betadisper TukeyHSD.betadisper
### Keywords: methods multivariate hplot

### ** Examples

data(varespec)

## Bray-Curtis distances between samples
dis <- vegdist(varespec)

## First 16 sites grazed, remaining 8 sites ungrazed
groups <- factor(c(rep(1,16), rep(2,8)), labels = c("grazed","ungrazed"))

## Calculate multivariate dispersions
mod <- betadisper(dis, groups)
mod

## Perform test
anova(mod)

## Permutation test for F
permutest(mod, pairwise = TRUE)

## Tukey's Honest Significant Differences
(mod.HSD <- TukeyHSD(mod))
plot(mod.HSD)

## Plot the groups and distances to centroids on the
## first two PCoA axes
plot(mod)

## Draw a boxplot of the distances to centroid for each group
boxplot(mod)

## simulate missing values in 'd' and 'group'
groups[c(2,20)] <- NA
dis[c(2, 20)] <- NA
mod2 <- betadisper(dis, groups) ## warnings
mod2
permutest(mod, control = permControl(nperm = 100))
anova(mod2)
plot(mod2)
boxplot(mod2)
plot(TukeyHSD(mod2))



